@@ -90,9 +90,13 @@ module Fog
           volumes.first.path if volumes and volumes.first
         end
 
-        def destroy(options={ :destroy_volumes => false})
+        def destroy(options={ :destroy_volumes => false, :flags => 0 })
           poweroff unless stopped?
-          service.vm_action(uuid, :undefine)
+          if options.fetch(:flags, 0).zero?
+            service.vm_action(uuid, :undefine)
+          else
+            service.vm_action(uuid, :undefine, options[:flags])
+          end
           volumes.each { |vol| vol.destroy } if options[:destroy_volumes]
           true
         end
@@ -407,13 +411,11 @@ module Fog
           ip_address = nil
           nic = self.nics.find {|nic| nic.mac==mac}
           if !nic.nil?
-            service.networks.all.each do |net|
-              if net.name == nic.network
-                leases = net.dhcp_leases(mac, 0)
-                # Assume the lease expiring last is the current IP address
-                ip_address = leases.sort_by { |lse| lse["expirytime"] }.last["ipaddr"] if !leases.empty?
-                break
-              end
+            net = service.networks.all(:name => nic.network).first
+            if !net.nil?
+              leases = net.dhcp_leases(mac, 0)
+              # Assume the lease expiring last is the current IP address
+              ip_address = leases.sort_by { |lse| lse["expirytime"] }.last["ipaddr"] if !leases.empty?
             end
           end
 
